parse_time

Function parse_time 

pub fn parse_time(value: &str) -> Result<Time, ParseTimeError>
Parses a time in HHMM format.

Errors

Returns an error if the value is not four ASCII digits or is outside the valid time range.