StringStorage

Trait StringStorage 

pub trait StringStorage:
    AsRef<str>
    + From<String>
    + Clone
    + Debug
    + Eq
    + Ord { }
Operations required of dynamic strings in generated models and builders.

Serde bounds are applied separately by generated codecs. Implemented automatically for compatible containers, including String and Box<str>.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> StringStorage for T
where T: AsRef<str> + From<String> + Clone + Debug + Eq + Ord,